==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fget_uuencode-1.6-1.2.8.tar.gz: get_uuencode/get_uuencode.php <==
<?php
    function get_uuencode_body(&$data) {
        global $REQUEST_URI, $startMessage, $passed_id, $ent_num; 
        global $urlMailbox, $color;
        global $get_uuencode_data, $get_uuencode_count;

        $space    = "[[:space:]]+";
        $mode     = "[0-7]{3}";
        $filename = "([^\n]+)";
        $uuheader = "(begin|begin-base64)".$space.$mode.$space.$filename.$space;

        $done      = False;
        $newdata   = $data[1];
        $output    = "";
        $get_uuencode_count = 0;
        do {
            if (ereg($uuheader,$newdata,$uu_body)) {
                $uu_match      = $uu_body[0];
                $uu_type       = $uu_body[1];
                $uu_filename   = $uu_body[2];
                if ($uu_type == 'begin') {
                    $end_tag = 'end';
                } else if ($uu_type == 'begin-base64') {
                    $end_tag = '====';
                } else {
                    break;
                }
                $bodyhead  = strpos($newdata, $uu_match);
                $bodystart = $bodyhead + strlen($uu_match);
                $bodyend   = strpos($newdata, $end_tag, $bodystart);
                if ($bodyend) {
                    $get_uuencode_count++;
                    $uu_data = substr($newdata, $bodystart, $bodyend - $bodystart);
                    $output .= substr($newdata, 0, $bodyhead);
                    $newdata = substr($newdata, $bodyend+strlen($end_tag));
                    $get_uuencode_data[$get_uuencode_count]["link"]     = "<a href=\"../plugins/get_uuencode/read_uuencode.php?start_message=$startMessage&amp;passed_id=$passed_id&amp;passed_ent_id=$ent_num&amp;mailbox=$urlMailbox&amp;get_uuencode_file=$get_uuencode_count\">$uu_filename</a>";
                    $get_uuencode_data[$get_uuencode_count]["filename"] = $uu_filename;
                    $get_uuencode_data[$get_uuencode_count]["size"]     = show_readable_size((strlen($uu_data))/1.35);
                } else {
                    $output .= substr($newdata, 0, $bodystart);
                    $newdata = substr($newdata, $bodystart);
                }
            } else {
                $output .= $newdata;
                $done = True;
            }
        } while (!$done);
        $data[1] = $output;
    }

    function get_uuencode_link () {
        global $REQUEST_URI, $startMessage, $passed_id, $ent_num, $urlMailbox,$color;
        global $get_uuencode_data, $get_uuencode_count;

        for ($i=1; $i <= $get_uuencode_count; $i++) {
            if (isset($get_uuencode_data[$i]["link"])) {
                echo "<table cols=1 cellspacing=0 width=100% border=0 cellpadding=2 bgcolor=$color[0]>";
                echo '<tr><td>';
                echo '&nbsp;&nbsp;'.$get_uuencode_data[$i]["link"];
                echo '&nbsp;<small><b>'.$get_uuencode_data[$i]["size"].'</b>&nbsp;&nbsp</small>';
                echo "</td></tr>\n</table>";
            }
        }
    }
?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fget_uuencode-2.0-1.4.0.tar.gz: get_uuencode/get_uuencode.php <==
<?php
    function get_uuencode_body(&$data) {
        global $REQUEST_URI, $startMessage, $passed_id, $passed_ent_id; 
        global $mailbox, $color;
        global $get_uuencode_data, $get_uuencode_count;

        $space    = "[[:space:]]+";
        $mode     = "[0-7]{3}";
        $filename = "([^\n]+)";
        $uuheader = "(begin|begin-base64)".$space.$mode.$space.$filename.$space;

        $done      = False;
        $newdata   = $data[1];
        $output    = "";
        $get_uuencode_count = 0;
        do {
            if (ereg($uuheader,$newdata,$uu_body)) {
                $uu_match      = $uu_body[0];
                $uu_type       = $uu_body[1];
                $uu_filename   = $uu_body[2];
                if ($uu_type == 'begin') {
                    $end_tag = 'end';
                } else if ($uu_type == 'begin-base64') {
                    $end_tag = '====';
                } else {
                    break;
                }
                $bodyhead  = strpos($newdata, $uu_match);
                $bodystart = $bodyhead + strlen($uu_match);
                $bodyend   = strpos($newdata, $end_tag, $bodystart);
                if ($bodyend) {
                    $get_uuencode_count++;
                    $uu_data = substr($newdata, $bodystart, $bodyend - $bodystart);
                    $output .= substr($newdata, 0, $bodyhead);
                    $newdata = substr($newdata, $bodyend+strlen($end_tag));
                    $get_uuencode_data[$get_uuencode_count]["link"]     = "<a href=\"../plugins/get_uuencode/read_uuencode.php?start_message=$startMessage&amp;passed_id=$passed_id&amp;passed_ent_id=$passed_ent_id&amp;mailbox=$mailbox&amp;get_uuencode_file=$get_uuencode_count\">$uu_filename</a>";
                    $get_uuencode_data[$get_uuencode_count]["filename"] = $uu_filename;
                    $get_uuencode_data[$get_uuencode_count]["size"]     = show_readable_size((strlen($uu_data))/1.35);
                } else {
                    $output .= substr($newdata, 0, $bodystart);
                    $newdata = substr($newdata, $bodystart);
                }
            } else {
                $output .= $newdata;
                $done = True;
            }
        } while (!$done);
        $data[1] = $output;
    }

    function get_uuencode_link () {
        global $REQUEST_URI, $startMessage, $passed_id, $passed_ent_id, $mailbox,$color;
        global $get_uuencode_data, $get_uuencode_count;

        for ($i=1; $i <= $get_uuencode_count; $i++) {
            if (isset($get_uuencode_data[$i]["link"])) {
                echo "<table cols=1 cellspacing=0 width=100% border=0 cellpadding=2 bgcolor=$color[0]>";
                echo '<tr><td>';
                echo '&nbsp;&nbsp;'.$get_uuencode_data[$i]["link"];
                echo '&nbsp;<small><b>'.$get_uuencode_data[$i]["size"].'</b>&nbsp;&nbsp</small>';
                echo "</td></tr>\n</table>";
            }
        }
    }
?>
